# coding: utf-8

# flake8: noqa
"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from assisted_service_client.models.add_hosts_cluster_create_params import AddHostsClusterCreateParams
from assisted_service_client.models.api_vip_connectivity_request import ApiVipConnectivityRequest
from assisted_service_client.models.api_vip_connectivity_response import ApiVipConnectivityResponse
from assisted_service_client.models.assisted_service_iso_create_params import AssistedServiceIsoCreateParams
from assisted_service_client.models.boot import Boot
from assisted_service_client.models.cluster import Cluster
from assisted_service_client.models.cluster_create_params import ClusterCreateParams
from assisted_service_client.models.cluster_default_config import ClusterDefaultConfig
from assisted_service_client.models.cluster_host_requirements import ClusterHostRequirements
from assisted_service_client.models.cluster_host_requirements_details import ClusterHostRequirementsDetails
from assisted_service_client.models.cluster_host_requirements_list import ClusterHostRequirementsList
from assisted_service_client.models.cluster_list import ClusterList
from assisted_service_client.models.cluster_progress_info import ClusterProgressInfo
from assisted_service_client.models.cluster_update_params import ClusterUpdateParams
from assisted_service_client.models.cluster_validation_id import ClusterValidationId
from assisted_service_client.models.clusterupdateparams_disks_selected_config import ClusterupdateparamsDisksSelectedConfig
from assisted_service_client.models.clusterupdateparams_hosts_machine_config_pool_names import ClusterupdateparamsHostsMachineConfigPoolNames
from assisted_service_client.models.clusterupdateparams_hosts_names import ClusterupdateparamsHostsNames
from assisted_service_client.models.clusterupdateparams_hosts_roles import ClusterupdateparamsHostsRoles
from assisted_service_client.models.completion_params import CompletionParams
from assisted_service_client.models.connectivity_check_host import ConnectivityCheckHost
from assisted_service_client.models.connectivity_check_nic import ConnectivityCheckNic
from assisted_service_client.models.connectivity_check_params import ConnectivityCheckParams
from assisted_service_client.models.connectivity_remote_host import ConnectivityRemoteHost
from assisted_service_client.models.connectivity_report import ConnectivityReport
from assisted_service_client.models.container_image_availability import ContainerImageAvailability
from assisted_service_client.models.container_image_availability_request import ContainerImageAvailabilityRequest
from assisted_service_client.models.container_image_availability_response import ContainerImageAvailabilityResponse
from assisted_service_client.models.container_image_availability_result import ContainerImageAvailabilityResult
from assisted_service_client.models.cpu import Cpu
from assisted_service_client.models.create_manifest_params import CreateManifestParams
from assisted_service_client.models.credentials import Credentials
from assisted_service_client.models.dhcp_allocation_request import DhcpAllocationRequest
from assisted_service_client.models.dhcp_allocation_response import DhcpAllocationResponse
from assisted_service_client.models.discovery_ignition_params import DiscoveryIgnitionParams
from assisted_service_client.models.disk import Disk
from assisted_service_client.models.disk_config_params import DiskConfigParams
from assisted_service_client.models.disk_info import DiskInfo
from assisted_service_client.models.disk_installation_eligibility import DiskInstallationEligibility
from assisted_service_client.models.disk_role import DiskRole
from assisted_service_client.models.disk_speed import DiskSpeed
from assisted_service_client.models.disk_speed_check_request import DiskSpeedCheckRequest
from assisted_service_client.models.disk_speed_check_response import DiskSpeedCheckResponse
from assisted_service_client.models.domain_resolution_request import DomainResolutionRequest
from assisted_service_client.models.domain_resolution_request_domains import DomainResolutionRequestDomains
from assisted_service_client.models.domain_resolution_response import DomainResolutionResponse
from assisted_service_client.models.domain_resolution_response_resolutions import DomainResolutionResponseResolutions
from assisted_service_client.models.error import Error
from assisted_service_client.models.event import Event
from assisted_service_client.models.event_list import EventList
from assisted_service_client.models.fio_perf_check_request import FioPerfCheckRequest
from assisted_service_client.models.fio_perf_check_response import FioPerfCheckResponse
from assisted_service_client.models.free_addresses_list import FreeAddressesList
from assisted_service_client.models.free_addresses_request import FreeAddressesRequest
from assisted_service_client.models.free_network_addresses import FreeNetworkAddresses
from assisted_service_client.models.free_networks_addresses import FreeNetworksAddresses
from assisted_service_client.models.host import Host
from assisted_service_client.models.host_create_params import HostCreateParams
from assisted_service_client.models.host_ignition_params import HostIgnitionParams
from assisted_service_client.models.host_list import HostList
from assisted_service_client.models.host_network import HostNetwork
from assisted_service_client.models.host_progress import HostProgress
from assisted_service_client.models.host_progress_info import HostProgressInfo
from assisted_service_client.models.host_registration_response import HostRegistrationResponse
from assisted_service_client.models.host_registration_response_next_step_runner_command import HostRegistrationResponseNextStepRunnerCommand
from assisted_service_client.models.host_requirements import HostRequirements
from assisted_service_client.models.host_requirements_role import HostRequirementsRole
from assisted_service_client.models.host_role import HostRole
from assisted_service_client.models.host_role_update_params import HostRoleUpdateParams
from assisted_service_client.models.host_stage import HostStage
from assisted_service_client.models.host_static_network_config import HostStaticNetworkConfig
from assisted_service_client.models.host_validation_id import HostValidationId
from assisted_service_client.models.image_create_params import ImageCreateParams
from assisted_service_client.models.image_info import ImageInfo
from assisted_service_client.models.image_type import ImageType
from assisted_service_client.models.infra_error import InfraError
from assisted_service_client.models.ingress_cert_params import IngressCertParams
from assisted_service_client.models.installer_args_params import InstallerArgsParams
from assisted_service_client.models.interface import Interface
from assisted_service_client.models.inventory import Inventory
from assisted_service_client.models.io_perf import IoPerf
from assisted_service_client.models.l2_connectivity import L2Connectivity
from assisted_service_client.models.l3_connectivity import L3Connectivity
from assisted_service_client.models.list_managed_domains import ListManagedDomains
from assisted_service_client.models.list_manifests import ListManifests
from assisted_service_client.models.list_versions import ListVersions
from assisted_service_client.models.logs_progress_params import LogsProgressParams
from assisted_service_client.models.logs_state import LogsState
from assisted_service_client.models.logs_type import LogsType
from assisted_service_client.models.mac_interface_map import MacInterfaceMap
from assisted_service_client.models.mac_interface_map_inner import MacInterfaceMapInner
from assisted_service_client.models.managed_domain import ManagedDomain
from assisted_service_client.models.manifest import Manifest
from assisted_service_client.models.memory import Memory
from assisted_service_client.models.monitored_operator import MonitoredOperator
from assisted_service_client.models.monitored_operators_list import MonitoredOperatorsList
from assisted_service_client.models.ntp_source import NtpSource
from assisted_service_client.models.ntp_synchronization_request import NtpSynchronizationRequest
from assisted_service_client.models.ntp_synchronization_response import NtpSynchronizationResponse
from assisted_service_client.models.openshift_version import OpenshiftVersion
from assisted_service_client.models.openshift_versions import OpenshiftVersions
from assisted_service_client.models.operator_create_params import OperatorCreateParams
from assisted_service_client.models.operator_host_requirements import OperatorHostRequirements
from assisted_service_client.models.operator_monitor_report import OperatorMonitorReport
from assisted_service_client.models.operator_properties import OperatorProperties
from assisted_service_client.models.operator_property import OperatorProperty
from assisted_service_client.models.operator_status import OperatorStatus
from assisted_service_client.models.operator_type import OperatorType
from assisted_service_client.models.presigned import Presigned
from assisted_service_client.models.source_state import SourceState
from assisted_service_client.models.step import Step
from assisted_service_client.models.step_reply import StepReply
from assisted_service_client.models.step_type import StepType
from assisted_service_client.models.steps import Steps
from assisted_service_client.models.steps_reply import StepsReply
from assisted_service_client.models.system_vendor import SystemVendor
from assisted_service_client.models.versions import Versions
